==> 0.1.0.tar.gz: lib/src/api_request_client.dart <==
import 'package:api_request/src/interceptors/token_interceptor.dart';
import 'package:api_request/src/interceptors/unauthenticated_interceptor.dart';
import 'package:dio/adapter.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';

import '../api_request.dart';

class RequestClient extends DioMixin implements Dio {
  static RequestClient? _instance;

  RequestClient._() {
    intConfig();
  }

  static RequestClient? get instance {
    if (_instance == null) {
      _instance = RequestClient._();
    }
    return _instance;
  }

  intConfig() {
    options = BaseOptions(
      baseUrl: ApiRequestOptions.instance!.baseUrl,
      queryParameters: ApiRequestOptions.instance?.defaultQueryParameters ?? {},
    );
    httpClientAdapter = DefaultHttpClientAdapter();
    if (!kReleaseMode) {
      interceptors.add(LogInterceptor(responseBody: true));
    }
    options.headers.addAll({Headers.acceptHeader: Headers.jsonContentType});
    if (ApiRequestOptions.instance != null) {
      if (ApiRequestOptions.instance?.unauthenticated != null) {
        addInterceptorOnce(UnauthenticatedInterceptor());
      }
    }
  }

  configAuth(bool authRequired) {
    bool hasInterceptor = interceptors.contains(TokenInterceptor());
    if (!authRequired && hasInterceptor) {
      interceptors.remove(TokenInterceptor());
    } else if (authRequired) {
      addInterceptorOnce(TokenInterceptor());
    }
  }

  addInterceptorOnce(Interceptor interceptor) {
    if (!interceptors.contains(interceptor)) {
      interceptors.add(interceptor);
    }
  }
}

==> 0.5.0.tar.gz: lib/src/api_request_client.dart <==
import 'package:api_request/src/interceptors/token_interceptor.dart';
import 'package:api_request/src/interceptors/unauthenticated_interceptor.dart';
import 'package:dio/dio.dart';
import 'package:flutter/foundation.dart';

import '../api_request.dart';

class RequestClient {
  static RequestClient? _instance;
  final Dio _dio = Dio();

  Dio get dio => _dio;

  RequestClient._() {
    intConfig();
  }

  static RequestClient? get instance {
    if (_instance == null) {
      _instance = RequestClient._();
    }
    return _instance;
  }

  intConfig() {
    _dio.options = BaseOptions(
      baseUrl: ApiRequestOptions.instance!.baseUrl,
      queryParameters: ApiRequestOptions.instance?.defaultQueryParameters ?? {},
    );
    if (!kReleaseMode) {
      _dio.interceptors.add(LogInterceptor(responseBody: true));
    }
    _dio.options.headers
        .addAll({Headers.acceptHeader: Headers.jsonContentType});
    if (ApiRequestOptions.instance != null) {
      if (ApiRequestOptions.instance?.unauthenticated != null) {
        addInterceptorOnce(UnauthenticatedInterceptor());
      }
    }
  }

  configAuth(bool authRequired) {
    bool hasInterceptor = _dio.interceptors.contains(TokenInterceptor());
    if (!authRequired && hasInterceptor) {
      _dio.interceptors.remove(TokenInterceptor());
    } else if (authRequired) {
      addInterceptorOnce(TokenInterceptor());
    }
  }

  addInterceptorOnce(Interceptor interceptor) {
    if (!_dio.interceptors.contains(interceptor)) {
      _dio.interceptors.add(interceptor);
    }
  }

  removeInterceptor(Interceptor interceptor) {
    if (!_dio.interceptors.contains(interceptor)) {
      _dio.interceptors.remove(interceptor);
    }
  }
}
